@@ -165,8 +165,7 @@ class Arena():
                 verify=self.ssl_verify,
                 )
         except requests.exceptions.SSLError:
-            print("Unable to establish a secure connection to Arena. Use a different internet connection or use `ssl_verify=False` to allow insecure requests.")
-            return
+            raise requests.exceptions.SSLError("Unable to establish a secure connection to Arena. Use a different internet connection or use `ssl_verify=False` to allow insecure requests.")
 
         if self._debug:
             print(f"{method.upper()} {endpoint} - {req.status_code}")
@@ -191,8 +190,8 @@ class Arena():
         return self._fetch("post", endpoint, data=data, files=files, **kwargs)
 
     #@disable
-    def _put(self, endpoint, data={}, **kwargs):
-        return self._fetch("put", endpoint, data=data, **kwargs)
+    def _put(self, endpoint, **kwargs):
+        return self._fetch("put", endpoint, data=kwargs)
 
     #@disable
     def _delete(self, endpoint, data={}, **kwargs):
